==> gorilla-notebook-0.4.11.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.events.js <==
goog.provide('pinkgorilla.events');
goog.require('cljs.core');
goog.require('day8.re_frame.http_fx');
goog.require('day8.re_frame.undo');
var module$node_modules$mousetrap$mousetrap=shadow.js.require("module$node_modules$mousetrap$mousetrap", {});
var module$node_modules$mousetrap_global_bind$mousetrap_global_bind=shadow.js.require("module$node_modules$mousetrap_global_bind$mousetrap_global_bind", {});
goog.require('pinkgorilla.events.common');
goog.require('pinkgorilla.events.config');
goog.require('pinkgorilla.events.message');
goog.require('pinkgorilla.events.notifications');
goog.require('pinkgorilla.events.palette');
goog.require('pinkgorilla.events.views');
goog.require('pinkgorilla.events.auth2');
goog.require('pinkgorilla.events.settings');
goog.require('pinkgorilla.events.notebook');
goog.require('pinkgorilla.events.storage');
goog.require('pinkgorilla.events.storage_save_dialog');
goog.require('pinkgorilla.events.storage_file');
goog.require('pinkgorilla.events.explore');
goog.require('pinkgorilla.events.kernel');
goog.require('pinkgorilla.events.kernel_toggle');
goog.require('pinkgorilla.events.kernel_docstring');
goog.require('pinkgorilla.explore.subs');
goog.require('pinkgorilla.explore.handlers');
pinkgorilla.events.common.reg_set_attr(new cljs.core.Keyword("pinkgorilla.events","set-navbar-menu-active?","pinkgorilla.events/set-navbar-menu-active?",293441318),new cljs.core.Keyword(null,"navbar-menu-active?","navbar-menu-active?",-381043544));
day8.re_frame.undo.undo_config_BANG_(new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"max-undos","max-undos",-911142923),(3),new cljs.core.Keyword(null,"harvest-fn","harvest-fn",9140059),(function (ratom){
var G__53475 = cljs.core.deref(ratom);
if((G__53475 == null)){
return null;
} else {
return new cljs.core.Keyword(null,"worksheet","worksheet",699486713).cljs$core$IFn$_invoke$arity$1(G__53475);
}
}),new cljs.core.Keyword(null,"reinstate-fn","reinstate-fn",1996128442),(function (ratom,value){
return cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$4(ratom,cljs.core.assoc_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"worksheet","worksheet",699486713)], null),value);
})], null));

//# sourceMappingURL=pinkgorilla.events.js.map

==> gorilla-notebook-0.4.16.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.events.js <==
goog.provide('pinkgorilla.events');
goog.require('cljs.core');
goog.require('day8.re_frame.http_fx');
goog.require('day8.re_frame.undo');
var module$node_modules$mousetrap$mousetrap=shadow.js.require("module$node_modules$mousetrap$mousetrap", {});
var module$node_modules$mousetrap_global_bind$mousetrap_global_bind=shadow.js.require("module$node_modules$mousetrap_global_bind$mousetrap_global_bind", {});
goog.require('pinkgorilla.events.common');
goog.require('pinkgorilla.events.config');
goog.require('pinkgorilla.events.message');
goog.require('pinkgorilla.events.notifications');
goog.require('pinkgorilla.events.palette');
goog.require('pinkgorilla.events.views');
goog.require('pinkgorilla.events.auth2');
goog.require('pinkgorilla.events.settings');
goog.require('pinkgorilla.events.notebook');
goog.require('pinkgorilla.events.storage');
goog.require('pinkgorilla.events.storage_save_dialog');
goog.require('pinkgorilla.events.storage_file');
goog.require('pinkgorilla.events.kernel');
goog.require('pinkgorilla.events.kernel_toggle');
goog.require('pinkgorilla.events.kernel_docstring');
goog.require('pinkgorilla.explore.subscriptions');
goog.require('pinkgorilla.explore.events');
pinkgorilla.events.common.reg_set_attr(new cljs.core.Keyword("pinkgorilla.events","set-navbar-menu-active?","pinkgorilla.events/set-navbar-menu-active?",293441318),new cljs.core.Keyword(null,"navbar-menu-active?","navbar-menu-active?",-381043544));
day8.re_frame.undo.undo_config_BANG_(new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"max-undos","max-undos",-911142923),(3),new cljs.core.Keyword(null,"harvest-fn","harvest-fn",9140059),(function (ratom){
var G__47689 = cljs.core.deref(ratom);
if((G__47689 == null)){
return null;
} else {
return new cljs.core.Keyword(null,"worksheet","worksheet",699486713).cljs$core$IFn$_invoke$arity$1(G__47689);
}
}),new cljs.core.Keyword(null,"reinstate-fn","reinstate-fn",1996128442),(function (ratom,value){
return cljs.core.swap_BANG_.cljs$core$IFn$_invoke$arity$4(ratom,cljs.core.assoc_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"worksheet","worksheet",699486713)], null),value);
})], null));

//# sourceMappingURL=pinkgorilla.events.js.map
